@@ -127,6 +127,28 @@ save_pixbuf_handle_success (ScreenshotApplication *self)
     }
 }
 
+static void
+screenshot_dialog_focus_cb (gint                   response,
+                            ScreenshotApplication *self)
+{
+  gtk_widget_grab_focus (screenshot_dialog_get_filename_entry (self->dialog));
+}
+
+static void
+screenshot_dialog_override_cb (gint                   response,
+                               ScreenshotApplication *self)
+{
+  if (response == GTK_RESPONSE_YES)
+    {
+      self->should_overwrite = TRUE;
+      screenshot_save_to_file (self);
+
+      return;
+    }
+
+  screenshot_dialog_focus_cb (response, self);
+}
+
 static void
 save_pixbuf_handle_error (ScreenshotApplication *self,
                           GError *error)
@@ -147,19 +169,13 @@ save_pixbuf_handle_error (ScreenshotApplication *self,
           g_autofree gchar *detail = g_strdup_printf (_("A file named “%s” already exists in “%s”"),
                                                       file_name, folder_name);
 
-          gint response = screenshot_show_dialog (GTK_WINDOW (dialog),
-                                                  GTK_MESSAGE_WARNING,
-                                                  GTK_BUTTONS_YES_NO,
-                                                  _("Overwrite existing file?"),
-                                                  detail);
-
-          if (response == GTK_RESPONSE_YES)
-            {
-              self->should_overwrite = TRUE;
-              screenshot_save_to_file (self);
-
-              return;
-            }
+          screenshot_show_dialog (GTK_WINDOW (dialog),
+                                  GTK_MESSAGE_WARNING,
+                                  GTK_BUTTONS_YES_NO,
+                                  _("Overwrite existing file?"),
+                                  detail,
+                                  (ScreenshotResponseFunc) screenshot_dialog_override_cb,
+                                  self);
         }
       else
         {
@@ -167,15 +183,14 @@ save_pixbuf_handle_error (ScreenshotApplication *self,
                                   GTK_MESSAGE_ERROR,
                                   GTK_BUTTONS_OK,
                                   _("Unable to capture a screenshot"),
-                                  _("Error creating file. Please choose another location and retry."));
+                                  _("Error creating file. Please choose another location and retry."),
+                                  (ScreenshotResponseFunc) screenshot_dialog_focus_cb,
+                                  dialog);
         }
-
-      gtk_widget_grab_focus (screenshot_dialog_get_filename_entry (dialog));
     }
   else
     {
       g_critical ("Unable to save the screenshot: %s", error->message);
-      screenshot_play_sound_effect ("dialog-error", _("Unable to capture a screenshot"));
       g_application_release (G_APPLICATION (self));
       if (screenshot_config->file != NULL)
         exit (EXIT_FAILURE);
@@ -426,10 +441,11 @@ build_filename_ready_cb (GObject *source,
                                 GTK_MESSAGE_ERROR,
                                 GTK_BUTTONS_OK,
                                 _("Unable to capture a screenshot"),
-                                _("Error creating file"));
+                                _("Error creating file"),
+                                NULL,
+                                NULL);
       else
         {
-          screenshot_play_sound_effect ("dialog-error", _("Unable to capture a screenshot"));
           if (screenshot_config->file != NULL)
             exit (EXIT_FAILURE);
         }
@@ -437,8 +453,6 @@ build_filename_ready_cb (GObject *source,
       return;
     }
 
-  screenshot_play_sound_effect ("screen-capture", _("Screenshot taken"));
-
   if (screenshot_config->interactive)
     {
       self->dialog = screenshot_dialog_new (GTK_APPLICATION (self),
@@ -455,6 +469,15 @@ build_filename_ready_cb (GObject *source,
     }
 }
 
+static void
+screenshot_release_cb (gint                   response,
+                       ScreenshotApplication *self)
+{
+  g_application_release (G_APPLICATION (self));
+  if (screenshot_config->file != NULL)
+    exit (EXIT_FAILURE);
+}
+
 static void
 finish_take_screenshot (ScreenshotApplication *self)
 {
@@ -472,13 +495,9 @@ finish_take_screenshot (ScreenshotApplication *self)
                                 GTK_MESSAGE_ERROR,
                                 GTK_BUTTONS_OK,
                                 _("Unable to capture a screenshot"),
-                                _("All possible methods failed"));
-      else
-        screenshot_play_sound_effect ("dialog-error", _("Unable to capture a screenshot"));
-
-      g_application_release (G_APPLICATION (self));
-      if (screenshot_config->file != NULL)
-        exit (EXIT_FAILURE);
+                                _("All possible methods failed"),
+                                (ScreenshotResponseFunc) screenshot_release_cb,
+                                self);
 
       return;
     }
@@ -488,8 +507,6 @@ finish_take_screenshot (ScreenshotApplication *self)
   if (screenshot_config->copy_to_clipboard)
     {
       screenshot_save_to_clipboard (self);
-      screenshot_play_sound_effect ("screen-capture", _("Screenshot taken"));
-      
       if (screenshot_config->file == NULL)
         {
           g_application_release (G_APPLICATION (self));
@@ -613,18 +630,6 @@ screenshot_application_handle_local_options (GApplication *app,
       exit (EXIT_SUCCESS);
     }
 
-  /* Start headless instances in non-unique mode */
-  if (!g_variant_dict_contains (options, "interactive"))
-    {
-      GApplicationFlags old_flags;
-
-      old_flags = g_application_get_flags (app);
-      if ((old_flags & G_APPLICATION_IS_SERVICE) == 0)
-        {
-          g_application_set_flags (app, old_flags | G_APPLICATION_NON_UNIQUE);
-        }
-    }
-
   return -1;
 }
 
@@ -732,6 +737,7 @@ action_about (GSimpleAction *action,
     "Emmanuele Bassi",
     "Jonathan Blandford",
     "Cosimo Cecchi",
+    "Alexander Mikhaylenko",
     NULL
   };
 
